@@ -36,6 +36,14 @@ class Scopus404Error(ScopusHtmlError):
     """Raised if a query yields a 404 error (Not Found for url)."""
 
 
+class Scopus413Error(ScopusHtmlError):
+    """Raised if a query yields a 413 error (Request Entity Too Large for url)."""
+
+
+class Scopus414Error(ScopusHtmlError):
+    """Raised if a query yields a 414 error (Request-URI Too Large for url)."""
+
+
 class Scopus429Error(ScopusHtmlError):
     """Raised if a query yields a 429 error (Quota exceeded)."""
 
@@ -44,3 +52,6 @@ class Scopus500Error(ScopusHtmlError):
     """Raised if a query yields a 500 error (Internal Server Error
     for url).
     """
+
+class Scopus502Error(ScopusHtmlError):
+    """Raised if a query yields a 502 error (Bad gateway for url)."""
