@@ -9,7 +9,9 @@ DEFAULT_PATHS = {
     'CitationOverview': expanduser('~/.scopus/citation_overview'),
     'ContentAffiliationRetrieval': expanduser('~/.scopus/affiliation_retrieval'),
     'ScopusSearch': expanduser('~/.scopus/scopus_search'),
-    'SerialTitle': expanduser('~/.scopus/serial_title')
+    'SerialSearch': expanduser('~/.scopus/serial_search'),
+    'SerialTitle': expanduser('~/.scopus/serial_title'),
+    'PlumXMetrics': expanduser('~/.scopus/plumx')
 }
 
 # URL prefix and suffixes for retrieval classes
@@ -19,7 +21,8 @@ RETRIEVAL_URL = {
     'AuthorRetrieval': RETRIEVAL_BASE + 'author/author_id/',
     'CitationOverview': RETRIEVAL_BASE + 'abstract/citations/',
     'ContentAffiliationRetrieval': RETRIEVAL_BASE + 'affiliation/affiliation_id/',
-    'SerialTitle': RETRIEVAL_BASE + 'serial/title/issn/'
+    'SerialTitle': RETRIEVAL_BASE + 'serial/title/issn/',
+    'PlumXMetrics': 'https://api.elsevier.com/analytics/plumx/'
 }
 
 # URL prefix and suffixes for search classes
@@ -27,5 +30,6 @@ SEARCH_BASE = 'https://api.elsevier.com/content/search/'
 SEARCH_URL = {
     'AffiliationSearch': SEARCH_BASE + 'affiliation',
     'AuthorSearch': SEARCH_BASE + 'author',
-    'ScopusSearch': SEARCH_BASE + 'scopus'
-}
\ No newline at end of file
+    'ScopusSearch': SEARCH_BASE + 'scopus',
+    'SerialSearch': RETRIEVAL_BASE + 'serial/title'
+}
